@@ -1,5 +1,6 @@
 import yaml
 
+from serverless.aws.functions.dynamodb import DynamoDBStreamFunction
 from serverless.aws.functions.event_bridge import EventBridgeFunction
 from serverless.aws.functions.generic import Function
 from serverless.aws.functions.http import HTTPFunction
@@ -161,6 +162,12 @@ class FunctionBuilder:
 
         return fn
 
+    def dynamodb_stream(self, stream, name, description, **kwargs):
+        fn = DynamoDBStreamFunction(stream, self.service, name, description, **kwargs)
+        self.service.functions.add(fn)
+
+        return fn
+
     def sqs(self, name, description, arn, **kwargs):
         fn = SQSFunction(self.service, name, description, arn, **kwargs)
         self.service.functions.add(fn)
